#
# Konstantin Volkov <wolf@virtuozzo.com>
#
# Copyright (c) 2017 Parallels IP Holdings GmbH
#
# This copyrighted material is made available to anyone wishing to use, modify,
# copy, or redistribute it subject to the terms and conditions of the GNU
# General Public License v.2.  This program is distributed in the hope that it
# will be useful, but WITHOUT ANY WARRANTY expressed or implied, including the
# implied warranties of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  Any Red Hat
# trademarks that are incorporated in the source code or documentation are not
# subject to the GNU General Public License and may only be used or replicated
# with the express permission of Parallels.
#

from pykickstart.base import *
from pykickstart.errors import *
from pykickstart.options import *

import gettext
import warnings
_ = lambda x: gettext.ldgettext("pykickstart", x)

class VZ7_RegisterVAagent(KickstartCommand):
    def __init__(self, writePriority=0, *args, **kwargs):
        KickstartCommand.__init__(self, writePriority, *args, **kwargs)
        self.op = self._getParser()

        self.mn_addr = kwargs.get("mn_addr", "")
        self.rootpw = kwargs.get("rootpw", "")

    def __str__(self):
        retval = KickstartCommand.__str__(self)

        if not self.enabled:
            return retval

        retval += "register_vaagent"

        if self.mn_addr:
            retval += " --mn_addr=%s" % self.mn_addr

        if self.rootpw:
            retval += " --rootpw=%s" % self.rootpw

        return retval + '\n'

    @property
    def enabled(self):
        return self.mn_addr

    def _getParser(self):
        op = KSOptionParser()
        op.add_option("--mn_addr", action="store", dest="mn_addr", default="")
        op.add_option("--rootpw", action="store", dest="rootpw", default="")

        return op

    def parse(self, args):
        (opts, extra) = self.op.parse_args(args=args, lineno=self.lineno)
        self._setToSelf(self.op, opts)

        if not self.mn_addr:
            raise KickstartValueError, formatErrorMsg(self.lineno,
                msg=_("vaagent requires MN ip or hostname for registration"))

        if not self.rootpw:
            raise KickstartValueError, formatErrorMsg(self.lineno,
                msg=_("vaagent requires MN root password for registration"))

        return self
